==> was-plugin-4.0.1-sources.jar: was/runtime/base.py <==
import types
import sys
import time

def printErrorAndExit(msg):
    print >> sys.stderr, msg
    sys.exit(1)

def printError(msg):
    print >> sys.stderr, msg

def toAdminConfigArgs(properties):
    args = []
    for propName, propValue in properties.items():
        if propValue != None:
            if isinstance(propValue, DictionaryObject):
                args.append([propName, str(propValue.name)])
            else:
                args.append([propName, str(propValue)])
    return args

def toAdminTaskArgs(properties):
    args = []
    for propName, propValue in properties.items():
        if propValue != None:
            if isinstance(propValue, DictionaryObject):
                args.extend(["-" + propName, str(propValue.name)])
            else:
                args.extend(["-" + propName, str(propValue)])
    return args

def validateNotEmpty(val, error):
    if val is None or val == "":
        printErrorAndExit(error)
    return val

def exitWithMessageIfEmpty(val, message, exitCode = 0):
    if val is None or val == "":
        if message:
            print message
        sys.exit(exitCode)
    return val

# Functions invoked by the PythonScriptStep

def saveConfiguration():
    if AdminConfig.hasChanges():
        print "Saving configuration"
        AdminConfig.save()

def connectFromDaemon():
    pass

def connectFromStandAloneScript():
    pass

def disconnectFromDaemon():
    pass

def disconnectFromStandAloneScript():
    saveConfiguration()

def runScriptFromDaemon(scriptPath):
    #Execute the script in its own global scope, so that functions defined in the script can find each other.
    execfile(scriptPath, globals().copy())
    saveConfiguration()

def disconnectFromDaemonForError():
    if AdminConfig.hasChanges():
        print "Discarding unsaved changes"
        AdminConfig.reset()

def findAllContainers(cell, onlyWasAppContainer=False):
    containers = []
    if cell.type == "was.UnmanagedServer":
        containers.append(cell)
    elif cell.type == "was.DeploymentManager":
        if (not onlyWasAppContainer):
            containers.append(cell)
        for cluster in cell.clusters:
            containers.append(cluster)
        for node in cell.nodeAgents:
            if (not onlyWasAppContainer):
                containers.append(node)
            for server in node.servers:
                containers.append(server)
    return containers

#*******************************************************************************************************
# convert a string as returned by AdminConfig.show[Attribute] to a Jython list
#*******************************************************************************************************
def wsadminToList(inStr):
  outList=[]
  if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
    inStr = inStr[1:-1]
    tmpList = inStr.split(" ")
  else:
    tmpList = inStr.split("\n")	 #splits for Windows or Linux
  for item in tmpList:
    item = item.rstrip();		 #removes any Windows "\r"
    if (len(item)>0):
      outList.append(item)
  return outList

#
# Transforms AdminConfig.show(xxx) to dictionary
# Example input: '[name webserver1]\n[nodeName was-61-appserver-node]'
# Will result in: {'name': 'webserver1', 'nodeName': 'was-61-appserver-node'}
#
def wsadminToDict(inStr):
    map = {}
    for l in inStr.splitlines():
        pieces = l[1:-1].split(" ")
        map[pieces[0]] = pieces[1]

    return map
#endDef

def mapToEmptyList(value, booleanValue = True):
    """ map value to empty list if it's empty or if booleanValue is false """
    if not value:
        return []
    if not booleanValue:
        return []
    return value

def noneToEmpty(value):
    """ map value to an empty string if it is None """
    if value is None:
        return ""
    else:
        return value

######################################################################
#
#Returns the WAS version
######################################################################
def getVersion(wasContainer):
    if hasattr(wasContainer,'version'):
       return wasContainer.version
    if hasattr(wasContainer, 'cell'):
       return wasContainer.cell.version
    if hasattr(wasContainer, 'node'):
       return wasContainer.node.cell.version


#######################################################################
#
# discovers AdminConfig object properties
#######################################################################

def inspectAdminConfigPropertiesCallback(container,prototype, canHandleAdminConfigPropertyTypeCallback, adminConfigPropertyTypeInspectCallback, listObjectsInContainerCallback=None):
  print "Retrieving list of %s objects in container %s" % (prototype.wasType, container.name)
  if listObjectsInContainerCallback:
    AdminConfigPropertiesList = listObjectsInContainerCallback(container, prototype)
  else:
    AdminConfigPropertiesList = wsadminToList(AdminConfig.list(prototype.wasType, AdminConfig.getid(container.containmentPath)))

  for p in AdminConfigPropertiesList:
    if canHandleAdminConfigPropertyTypeCallback is None or canHandleAdminConfigPropertyTypeCallback(p):
      name = AdminConfig.showAttribute(p, 'name')
      print "Discovered %s %s in container %s" % (prototype.type, name, container.name)
      deployedId = container.id + '/' + name
      discovered(deployedId, prototype.type)
      adminConfigPropertyTypeInspectCallback(deployedId, name, p, prototype)
      inspectedItem(deployedId)

#################################################################
#
#inspects properties of the Deployed
#################################################################

def inspectDeployedProperties(id, name, propertyId, prototype, ignoredProperties = ['name']):
  print "Inspecting %s %s" % (prototype.type, name)
  for p in prototype.getExposedPropertyNames():
    if p not in ignoredProperties:
      val = AdminConfig.showAttribute(propertyId, p)
      if val == '[]': val = []
      inspectedProperty(id, p, val)

#################################################################
#
#synchronize all the Nodes
#################################################################

def syncNodes(cell):
    for node in cell.nodeAgents:
        nodeName = node.name
        print "Synchronizing '%s'" % (nodeName)
        sync = AdminControl.completeObjectName("type=NodeSync,node=%s,*" % (nodeName))
        if sync == '':
            raise "Node '%s' does not exist or is not running" % (nodeName)
        AdminControl.invoke(sync, 'sync');
        print "Completed synchronization of '%s'" % (nodeName)

def isServerRunning(serverName) :
    return AdminControl.completeObjectName("WebSphere:type=Server,name=%s,*" % (serverName)) != ""

def isClusterRunning(clusterName) :
    cluster = AdminControl.completeObjectName("WebSphere:type=Cluster,name=%s,*" % (clusterName))
    if cluster != "":
        state = AdminControl.getAttribute(cluster, 'state')
        return state != "websphere.cluster.stopped"
    return False

###################################################################
#
#Creating,deleting and Inspection of custom properties...
###################################################################
def createOrUpdateCustomProps(parentId, customProp, deployed):
    if hasattr(deployed, 'customProperties'):
        existingPropIds = {}
        for propId in wsadminToList(AdminConfig.list(customProp, parentId)):
            existingPropIds[AdminConfig.showAttribute(propId, "name")] = propId

        for name, value in deployed.customProperties.items():
            if existingPropIds.has_key(name):
                print "Updating custom property '%s' for '%s'" % (name, deployed.name)
                AdminConfig.modify(existingPropIds.get(name), [['value', value]])
            else:
                print "Creating custom property '%s' for '%s'" % (name, deployed.name)
                AdminConfig.create(customProp, parentId, [['name', name], ['value', value]])

def createCustomProps(parentId, customProp, deployed):
    if hasattr(deployed, 'customProperties'):
        for name, value in deployed.customProperties.items():
            print "Creating Custom Property '%s' for '%s'" % (name, parentId)
            AdminConfig.create(customProp, parentId, [['name', name], ['value', value]])

def removeCustomProps(parentId, customProp):
    customProperties = wsadminToList(AdminConfig.showAttribute(parentId, customProp))
    for customPropId in customProperties:
        print "Removing Custom Property %s" %(customPropId)
        AdminConfig.remove(customPropId)

def inspectCustomProperties(deployedId, nestedPropId, deployitProperty):
    customProperties = {}
    if nestedPropId:
        for propsetItem in nestedPropId:
            customProperties[AdminConfig.showAttribute(propsetItem, "name")] = AdminConfig.showAttribute(propsetItem, "value")
        if len(customProperties) > 0:
            inspectedProperty(deployedId, deployitProperty, customProperties)

#############################################################################
#
#Creating, Deleting, Inspection of J2EE Resource Properties
#############################################################################
def inspectNestedJ2EEResourceProperties(deployedId, resourceId, nestedProperty, deployitProperty):
    nestedResourcePropId = AdminConfig.showAttribute(resourceId, nestedProperty)
    if nestedResourcePropId:
        nestedPropId = wsadminToList(AdminConfig.list("J2EEResourceProperty", nestedResourcePropId))
        inspectCustomProperties(deployedId, nestedPropId, deployitProperty)

def createOrUpdateJ2EEResourceProperties(resourceId, deployed):
    nestedResourcePropId = AdminConfig.showAttribute(resourceId, 'propertySet')
    if nestedResourcePropId is None:
        print "Creating J2EE Resource Property set for '%s'" % deployed.name
        nestedResourcePropId = AdminConfig.create('J2EEResourcePropertySet', resourceId, [])
    createOrUpdateCustomProps(nestedResourcePropId, 'J2EEResourceProperty', deployed)

def createJ2EEResourceProperties(resourceId, deployed):
    nestedResourcePropId = AdminConfig.showAttribute(resourceId, 'propertySet')
    if nestedResourcePropId is None:
        print "Creating J2EE Resource Property set for '%s'" % (resourceId)
        nestedResourcePropId = AdminConfig.create('J2EEResourcePropertySet', resourceId, [])
    createCustomProps(nestedResourcePropId, 'J2EEResourceProperty', deployed)

def removeJ2EEResourceProperties(resourceId):
    nestedResourcePropertySetId = AdminConfig.showAttribute(resourceId, 'propertySet')
    if nestedResourcePropertySetId:
        removeCustomProps(nestedResourcePropertySetId, 'resourceProperties')

#######################################################################
# Create Connection or Session Pool on parentId
#######################################################################
def configureConnectionPool(parentId, poolArgs, attributeName):
    print "Creating '%s' with '%s'" % (attributeName, poolArgs)
    AdminConfig.create('ConnectionPool', parentId, poolArgs, attributeName)

#######################################################################
# Inspection and filtering of attributes not supported by the container
#######################################################################
def excludeUnsupportedProperties(deployed, exposedProperties):
    """Configure property values for specific WAS version. Properties not applicable
    to the current container version will be removed from the property set.
    * deployed - deployed instance
    * exposedProperties - properties exposed by the CI to the container"""
    invalidAttrs = getUnsupportedTypeAttrs(deployed.wasType, exposedProperties.keys())
    for invalidAttr in invalidAttrs:
        del exposedProperties[invalidAttr]
    return exposedProperties

def getUnsupportedTypeAttrs(wasType, attributes):
    """Diff the CI attributes and container supported attributes and return the list of attributes
    not supported by the container instance.
    * wasType - name of the AdminConfig object type as in XML configuration files
    * attributes - CI property names
    """
    supportedAttrs = getConfigTypeAttrs(wasType)
    invalidAttrs = [attr for attr in attributes if attr not in supportedAttrs]
    if invalidAttrs:
        print "WARN: Following properties are ignored for the current WAS Server version: %s" % invalidAttrs
    return invalidAttrs

def getConfigTypeAttrs(wasType):
    """Return the list of top level properties for the given wasType.
    * wasType - name of the AdminConfig object type as in XML configuration files"""
    cmdOut = AdminConfig.attributes(wasType)
    propertyLines = cmdOut.splitlines()
    propertyNames = [x.split()[0] for x in propertyLines]
    return propertyNames

def allNoneToEmpty(exposedProperties):
    """Convert values of all none set properties to empty so they are included
    into the AdminConfig.modify command and properties are correctly reset during modify.
    * exposedProperties - properties exposed by the CI to the container"""
    for key in [key for key in exposedProperties.keys() if exposedProperties[key] is None]:
        exposedProperties[key] = noneToEmpty(exposedProperties[key])
    return exposedProperties

==> was-plugin-4.5.4-sources.jar: was/runtime/base.py <==
import types
import sys
import time
import re

def printErrorAndExit(msg):
    print >> sys.stderr, msg
    sys.exit(1)

def printError(msg):
    print >> sys.stderr, msg

def toAdminConfigArgs(properties):
    args = []
    for propName, propValue in properties.items():
        if propValue != None:
            if isinstance(propValue, DictionaryObject):
                args.append([propName, str(propValue.name)])
            else:
                args.append([propName, str(propValue)])
    return args

def listToAdminTaskArgs(props):
    if type(props) is types.ListType:
        return '[' + reduce(lambda h, t: listToAdminTaskArgs(h) + " " + listToAdminTaskArgs(t), props) + ']'
    return props

def toAdminTaskArgs(properties):
    args = []
    for propName, propValue in properties.items():
        if propValue != None:
            if isinstance(propValue, DictionaryObject):
                args.extend(["-" + propName, str(propValue.name)])
            else:
                args.extend(["-" + propName, str(propValue)])
    return args

def validateNotEmpty(val, error):
    if val is None or val == "" or val == []:
        printErrorAndExit(error)
    return val

def exitWithMessageIfEmpty(val, message, exitCode = 0):
    if val is None or val == "" or val == []:
        if message:
            print message
        sys.exit(exitCode)
    return val

# Functions invoked by the PythonScriptStep

def saveConfiguration():
    if AdminConfig.hasChanges():
        print "Saving configuration"
        AdminConfig.save()

def connectFromDaemon():
    pass

def connectFromStandAloneScript():
    pass

def disconnectFromDaemon():
    pass

def disconnectFromStandAloneScript():
    saveConfiguration()

def runScriptFromDaemon(scriptPath):
    #Execute the script in its own global scope, so that functions defined in the script can find each other.
    execfile(scriptPath, globals().copy())
    saveConfiguration()

def disconnectFromDaemonForError():
    if AdminConfig.hasChanges():
        print "Discarding unsaved changes"
        AdminConfig.reset()

def findAllContainers(cell, onlyWasAppContainer=False):
    containers = []
    if cell.type == "was.UnmanagedServer":
        containers.append(cell)
    elif cell.type == "was.DeploymentManager":
        if (not onlyWasAppContainer):
            containers.append(cell)
        for cluster in cell.clusters:
            containers.append(cluster)
        for node in cell.nodeAgents:
            if (not onlyWasAppContainer):
                containers.append(node)
            for server in node.servers:
                containers.append(server)
    return containers

#*******************************************************************************************************
# convert a string as returned by AdminConfig.show[Attribute] to a Jython list
#*******************************************************************************************************
def wsadminToList(inStr):
  outList=[]
  if (len(inStr)>0 and inStr[0]=='[' and inStr[-1]==']'):
    inStr = inStr[1:-1]
    tmpList = re.findall(r'[^"\s]\S*|".+?"', inStr) # split only on spaces that are not in apostrophes - names may also contain spaces
  else:
    tmpList = inStr.split("\n")	 #splits for Windows or Linux
  for item in tmpList:
    item = item.rstrip();		 #removes any Windows "\r"
    if (len(item)>0):
      outList.append(item)
  return outList

#
# Transforms AdminConfig.show(xxx) to dictionary
# Example input: '[name webserver1]\n[nodeName was-61-appserver-node]'
# Will result in: {'name': 'webserver1', 'nodeName': 'was-61-appserver-node'}
#
def wsadminToDict(inStr):
    map = {}
    for l in inStr.splitlines():
        pieces = l[1:-1].split(" ", 1)
        val = re.sub(r'^"|"$', '', pieces[1])
        if (len(val) > 0 and val[0] == '[' and val[-1] == ']'):
            val = wsadminToList(val)
        map[pieces[0]] = val
    return map
#endDef

def mapToEmptyList(value, booleanValue = True):
    """ map value to empty list if it's empty or if booleanValue is false """
    if not value:
        return []
    if not booleanValue:
        return []
    return value

def noneToEmpty(value):
    """ map value to an empty string if it is None """
    if value is None:
        return ''
    else:
        return value

######################################################################
#
#Returns the WAS version
######################################################################
def getVersion(wasContainer):
    if hasattr(wasContainer,'version'):
       return wasContainer.version
    if hasattr(wasContainer, 'cell'):
       return wasContainer.cell.version
    if hasattr(wasContainer, 'node'):
       return wasContainer.node.cell.version


#######################################################################
#
# discovers AdminConfig object properties
#######################################################################

def inspectAdminConfigPropertiesCallback(container,prototype, canHandleAdminConfigPropertyTypeCallback, adminConfigPropertyTypeInspectCallback, listObjectsInContainerCallback=None):
  print "Retrieving list of %s objects in container %s" % (prototype.wasType, container.name)
  if listObjectsInContainerCallback:
    AdminConfigPropertiesList = listObjectsInContainerCallback(container, prototype)
  else:
    AdminConfigPropertiesList = wsadminToList(AdminConfig.list(prototype.wasType, AdminConfig.getid(container.containmentPath)))

  for p in AdminConfigPropertiesList:
    if canHandleAdminConfigPropertyTypeCallback is None or canHandleAdminConfigPropertyTypeCallback(p):
      name = AdminConfig.showAttribute(p, 'name')
      print "Discovered %s %s in container %s" % (prototype.type, name, container.name)
      deployedId = container.id + '/' + name
      discovered(deployedId, prototype.type)
      adminConfigPropertyTypeInspectCallback(deployedId, name, p, prototype)
      inspectedItem(deployedId)

#################################################################
#
#inspects properties of the Deployed
#################################################################

def inspectDeployedProperties(id, name, propertyId, prototype, ignoredProperties = ['name']):
  print "Inspecting %s %s" % (prototype.type, name)
  for p in prototype.getExposedPropertyNames():
    if p not in ignoredProperties:
      val = AdminConfig.showAttribute(propertyId, p)
      if val == '[]': val = []
      inspectedProperty(id, p, val)

#################################################################
#
#synchronize all the Nodes
#################################################################

def syncNodes(cell, full=None):
    for node in cell.nodeAgents:
        nodeName = node.name
        syncNode(nodeName, full)

def syncNode(nodeName, full=None):
    # WebSphere Application Server synchronization process explained: http://www-01.ibm.com/support/docview.wss?uid=swg21233075
    # What is file synchronization and how does it work?: http://www-01.ibm.com/support/docview.wss?uid=swg21108407
    print "Synchronizing node '%s'" % (nodeName)
    if full == 'true':
        print "Full sync of node %s started" % nodeName
        configRepository = AdminControl.completeObjectName('type=ConfigRepository,process=nodeagent,node=%s,*' % nodeName)
        if configRepository:
            AdminControl.invoke(configRepository, 'refreshRepositoryEpoch')
            print "Full sync of node %s refresh completed" % nodeName
        else:
            print "Unable to get ConfigRepository for node %s. Will not trigger full synchronization." % nodeName
    nodeSync = AdminControl.completeObjectName('type=NodeSync,node=%s,*' % nodeName);
    if nodeSync:
        count = 0
        isSynchronized = AdminControl.invoke(nodeSync, 'isNodeSynchronized')
        while isSynchronized != 'true' and count < 5:
            print "Node %s is not synchronized. Starting synchronization." % (nodeName)
            AdminControl.invoke(nodeSync, 'sync');
            isSynchronized = AdminControl.invoke(nodeSync, 'isNodeSynchronized')
            count = count + 1
        print "Completed synchronization of '%s'" % (nodeName)
    else:
        raise "Node '%s' does not exist or is not running" % (nodeName)


def isServerRunning(nodeName, serverName) :
    return AdminControl.completeObjectName("WebSphere:type=Server,node=%s,name=%s,*" % (nodeName, serverName)) != ""

def isClusterRunning(clusterName) :
    cluster = AdminControl.completeObjectName("WebSphere:type=Cluster,name=%s,*" % (clusterName))
    if cluster != "":
        state = AdminControl.getAttribute(cluster, 'state')
        return state != "websphere.cluster.stopped"
    return False

###################################################################
#
#Creating,deleting and Inspection of custom properties...
###################################################################
def createOrUpdateCustomProps(parentId, customProp, deployed):
    if hasattr(deployed, 'customProperties'):
        existingPropIds = {}
        for propId in wsadminToList(AdminConfig.list(customProp, parentId)):
            existingPropIds[AdminConfig.showAttribute(propId, "name")] = propId

        for name, value in deployed.customProperties.items():
            if existingPropIds.has_key(name):
                print "Updating custom property '%s' for '%s'" % (name, parentId)
                AdminConfig.modify(existingPropIds.get(name), [['value', value]])
            else:
                print "Creating custom property '%s' for '%s'" % (name, parentId)
                AdminConfig.create(customProp, parentId, [['name', name], ['value', value]])

def createCustomProps(parentId, customProp, deployed):
    if hasattr(deployed, 'customProperties'):
        for name, value in deployed.customProperties.items():
            print "Creating Custom Property '%s' for '%s'" % (name, parentId)
            AdminConfig.create(customProp, parentId, [['name', name], ['value', value]])

def removeCustomProps(parentId, customProp):
    customProperties = wsadminToList(AdminConfig.showAttribute(parentId, customProp))
    for customPropId in customProperties:
        print "Removing Custom Property %s" %(customPropId)
        AdminConfig.remove(customPropId)

def inspectCustomProperties(deployedId, nestedPropId, deployitProperty):
    customProperties = {}
    if nestedPropId:
        for propsetItem in nestedPropId:
            customProperties[AdminConfig.showAttribute(propsetItem, "name")] = AdminConfig.showAttribute(propsetItem, "value")
        if len(customProperties) > 0:
            inspectedProperty(deployedId, deployitProperty, customProperties)

#############################################################################
#
#Creating, Deleting, Inspection of J2EE Resource Properties
#############################################################################
def inspectNestedJ2EEResourceProperties(deployedId, resourceId, nestedProperty, deployitProperty):
    nestedResourcePropId = AdminConfig.showAttribute(resourceId, nestedProperty)
    if nestedResourcePropId:
        nestedPropId = wsadminToList(AdminConfig.list("J2EEResourceProperty", nestedResourcePropId))
        inspectCustomProperties(deployedId, nestedPropId, deployitProperty)

def createOrUpdateJ2EEResourceProperties(resourceId, deployed):
    nestedResourcePropId = AdminConfig.showAttribute(resourceId, 'propertySet')
    if nestedResourcePropId is None:
        print "Creating J2EE Resource Property set for '%s'" % deployed.name
        nestedResourcePropId = AdminConfig.create('J2EEResourcePropertySet', resourceId, [])
    createOrUpdateCustomProps(nestedResourcePropId, 'J2EEResourceProperty', deployed)

def createJ2EEResourceProperties(resourceId, deployed):
    nestedResourcePropId = AdminConfig.showAttribute(resourceId, 'propertySet')
    if nestedResourcePropId is None:
        print "Creating J2EE Resource Property set for '%s'" % (resourceId)
        nestedResourcePropId = AdminConfig.create('J2EEResourcePropertySet', resourceId, [])
    createCustomProps(nestedResourcePropId, 'J2EEResourceProperty', deployed)

def removeJ2EEResourceProperties(resourceId):
    nestedResourcePropertySetId = AdminConfig.showAttribute(resourceId, 'propertySet')
    if nestedResourcePropertySetId:
        removeCustomProps(nestedResourcePropertySetId, 'resourceProperties')

#######################################################################
# Create Connection or Session Pool on parentId
#######################################################################
def configureConnectionPool(parentId, poolArgs, attributeName):
    print "Creating '%s' with '%s'" % (attributeName, poolArgs)
    AdminConfig.create('ConnectionPool', parentId, poolArgs, attributeName)

#######################################################################
# Inspection and filtering of attributes not supported by the container
#######################################################################
def excludeUnsupportedProperties(deployedType, exposedProperties, printWarning = True):
    """Configure property values for specific WAS version. Properties not applicable
    to the current container version will be removed from the property set.
    * deployedType - deployed type instance
    * exposedProperties - properties exposed by the CI to the container"""
    type = deployedType
    if hasattr(deployedType, 'wasType'):
        type = deployedType.wasType
    invalidAttrs = getUnsupportedTypeAttrs(type, exposedProperties.keys(), printWarning)
    for invalidAttr in invalidAttrs:
        del exposedProperties[invalidAttr]
    return exposedProperties

def getUnsupportedTypeAttrs(wasType, attributes, printWarning = True):
    """Diff the CI attributes and container supported attributes and return the list of attributes
    not supported by the container instance.
    * wasType - name of the AdminConfig object type as in XML configuration files
    * attributes - CI property names
    """
    supportedAttrs = getConfigTypeAttrs(wasType)
    invalidAttrs = [attr for attr in attributes if attr not in supportedAttrs]
    if printWarning and invalidAttrs:
        print "WARN: Following properties of type '%s' are ignored for the current WAS Server version: %s" % (wasType, invalidAttrs)
    return invalidAttrs

def getConfigTypeAttrs(wasType):
    """Return the list of top level properties for the given wasType.
    * wasType - name of the AdminConfig object type as in XML configuration files"""
    cmdOut = AdminConfig.attributes(wasType)
    propertyLines = cmdOut.splitlines()
    propertyNames = [x.split()[0] for x in propertyLines]
    return propertyNames

# reset attributes if none is encountered
def allNoneToEmpty(exposedProperties):
    """Convert values of all none set properties to empty so they are included
    into the AdminConfig.modify command and properties are correctly reset during modify.
    * exposedProperties - properties exposed by the CI to the container"""
    for key in [key for key in exposedProperties.keys() if exposedProperties[key] is None]:
        exposedProperties[key] = noneToEmpty(exposedProperties[key])
    return exposedProperties

def getObjectType(container, resourceId):
    """Return WebSphere AdminConfig object type. WAS6.1 doesn't implement the getObjectType
    method, so fallback to parsing the WebSphere ID is used.
    * container - current container
    * resourceId - WebSphere ID (e.g. existing-dyn-cluster(cells/vagrantCell01/clusters/existing-dyn-cluster|cluster.xml#ServerCluster_1402583315051))"""
    if getVersion(container) == 'WAS_61':
        return resourceId[resourceId.rfind("#")+1:resourceId.rfind("_")]
    else:
        return AdminConfig.getObjectType(resourceId)

## WAS 6 specific methods:
def _getConfigService():
    cspField=AdminConfig.__class__.getDeclaredField('configServiceProxy')
    cspField.setAccessible(1)
    csp=cspField.get(AdminConfig)
    return csp

def _getObjectName(configId):
    """
    Takes configuration object id returned by AdminConfig.getid and returns valid object name that can be passed to ConfigurationServiceProxy
    (i.e. ObjectName that has was specific attributes defined in com.ibm.websphere.management.configservice.ConfigService)
    :param configId: configuration object id returned by AdminConfig.getid
    :return: object name that can be passed to ConfigurationServiceProxy
    """
    configHelperField=AdminConfig.class.getDeclaredField('configHelper')
    configHelperField.setAccessible(1)
    configHelper = configHelperField.get(AdminConfig)
    on = configHelper.stringToObjectName(configId)
    return on

def unsetAttributes(configId, attrs):
    """
    WAS 6 specific: unset specified properties on configuration object using ConfigService

    :param configId:
    :param props:
    """
    on = _getObjectName(configId)
    csp = _getConfigService()
    session=AdminConfig.currentSession
    csp.unsetAttributes(session, on, attrs)
